from setuptools import setup


setup(
    name='sf-b4',
    version='1.4.2',
    description='SkillFactory',
    author='Roman Brick',
    author_email='romanbrick@icloud.cloud',
    zip_safe=False)

